<?php # $Id: serendipity_lang_es.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) by Luis Cervantes <LuisCervantes@ono.com>,
#                    Manuel Garca <lendulado@gmail.com>,
#                    Rodrigo Lazo <rlazo.paz@gmail.com>,
#                    Melvin D. Nava <mdnava@dotcomo.com>,
# Fixed entities by Leandro Lucarella <luca@llucax.hn.org>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-15');
@define('SQL_CHARSET', 'latin2');
@define('DATE_LOCALES', 'es_ES.ISO8859-15, es_ES.ISO8859-1, spanish, sp, es, es_ES, es-ES, es_ES.ISO_8859-15, es_ES.ISO_8859-1');
@define('DATE_FORMAT_ENTRY', '%A, %e de %B del %Y');
@define('DATE_FORMAT_SHORT', '%d.%m.%Y %H:%M');
@define('WYSIWYG_LANG', 'es');
@define('LANG_DIRECTION', 'ltr');

/* rlazo[20061114]: dado que el espaol tiene varias traducciones para ciertas
 * palabras sera bueno mantener una misma traduccin para ciertas
 * palabras comunes (tratando de seguir http://es.tldp.org/ORCA/glosario.html):
 *
 * password -> contrasea
 * file -> fichero? (se podra utilizar archivo para referirse a las entradas pasadas)
 */
@define('SERENDIPITY_ADMIN_SUITE', 'Suite de Administracin de Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', 'Debes identificarte para ver esta pgina');
@define('APPEARANCE', 'Apariencia');
@define('MANAGE_STYLES', 'Gestin de estilos');
@define('CONFIGURE_PLUGINS', 'Configurar extensiones');
@define('CONFIGURATION', 'Configuracin');
@define('BACK_TO_BLOG', 'Volver al weblog');
@define('LOGOUT', 'Desconectar');
@define('LOGGEDOUT', 'Desconectado');
@define('CREATE_NEW_CAT', 'Crear una categora nueva');
@define('CREATE', 'Crear');
@define('SAVE', 'Guardar');
@define('NAME', 'Nombre');
@define('I_WANT_THUMB', 'Quiero usar la miniatura en mi entrada.');
@define('I_WANT_BIG_IMAGE', 'Quiero usar la imagen ms grande en mi entrada.');
@define('I_WANT_NO_LINK', ' Quiero que aparezca como una imagen');
@define('I_WANT_IT_TO_LINK', 'Quiero que aparezca como un enlace a esta URL:');
@define('BACK', 'Atrs');
@define('FORWARD', 'Seguir');
@define('ANONYMOUS', 'Annimo');
@define('NEW_TRACKBACK_TO', 'Nueva referencia hecha para');
@define('NEW_COMMENT_TO', 'Nuevo comentario para');
@define('RECENT', 'Recientes...');
@define('OLDER', 'Antiguos...');
@define('DONE', 'Hecho');
@define('WELCOME_BACK', 'Bienvenido de nuevo,');
@define('TITLE', 'Ttulo');
@define('DESCRIPTION', 'Descripcin');
@define('PLACEMENT', 'Localizacin');
@define('DELETE', 'Borrar');
@define('SAVE', 'Guardar');
@define('UP', 'ARRIBA');
@define('DOWN', 'ABAJO');
@define('ENTRIES', 'entradas');
@define('NEW_ENTRY', 'Nueva entrada');
@define('EDIT_ENTRIES', 'Editar entradas');
@define('CATEGORIES', 'Categoras');
@define('WARNING_THIS_BLAHBLAH', "ATENCIN:\\nPuede tardar si hay muchas imgenes que no tienen miniatura.");
@define('CREATE_THUMBS', 'Crear las miniaturas');
@define('MANAGE_IMAGES', 'Gestin de imgenes');
@define('NAME', 'Nombre');
@define('EMAIL', 'Correo electrnico');
@define('HOMEPAGE', 'URL personal');
@define('COMMENT', 'Comentario');
@define('REMEMBER_INFO', 'Recordar la informacin?');
@define('SUBMIT_COMMENT', 'Enviar comentario');
@define('NO_ENTRIES_TO_PRINT', 'No hay entradas para mostrar');
@define('COMMENTS', 'Comentarios');
@define('ADD_COMMENT', 'Aadir comentario');
@define('NO_COMMENTS', 'No hay comentarios');
@define('POSTED_BY', 'Publicado por');
@define('ON', 'activado');
@define('A_NEW_COMMENT_BLAHBLAH', 'Se ha realizado un nuevo comentario en tu blog "%s", para la entrada titulada "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Se ha realizado una nueva referencia a la entrada titulada "%s".');
@define('NO_CATEGORY', 'No existe la categora');
@define('ENTRY_BODY', 'Texto de la entrada');
@define('EXTENDED_BODY', 'Texto ampliado');
@define('CATEGORY', 'Categora');
@define('EDIT', 'Editar');
@define('NO_ENTRIES_BLAHBLAH', 'No se han encontrado resultados para la bsqueda %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'La bsqueda para %s ha obtenido %s resultados:');
@define('IMAGE', 'Imagen');
@define('ERROR_FILE_NOT_EXISTS', 'Error: El fichero antiguo no existe!');
@define('ERROR_FILE_EXISTS', 'Error: Un fichero con ese nombre ya existe, selecciona otro!');
@define('ERROR_SOMETHING', 'Error: Algo est mal.');
@define('ADDING_IMAGE', 'Aadiendo imagen...');
@define('THUMB_CREATED_DONE', 'Miniatura creada.<br />Hecho.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Error: El fichero ya existe en el sistema!');
@define('GO', 'Ir!');
@define('NEWSIZE', 'Nuevo tamao: ');
@define('RESIZE_BLAHBLAH', '<b>Cambiar tamao %s</b><p>');
@define('ORIGINAL_SIZE', 'Tamao original: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Aqu puedes ajustar el nuevo tamao de la imagen. Si quieres mantener las proporciones slo introduce uno de los valores y presiona la tecla tabulador (TAB), de esta forma se ajustar automticamente:');
@define('DATE_FORMAT_1', 'd.m.Y');
@define('QUICKJUMP_CALENDAR', 'Calendario rpido');
@define('QUICKSEARCH', 'Buscar');
@define('SEARCH_FOR_ENTRY', 'Busca una entrada');
@define('ARCHIVES', 'Archivos');
@define('BROWSE_ARCHIVES', 'Navega los archivos por mes');
@define('TOP_REFERRER', 'Sitios asociados');
@define('SHOWS_TOP_SITES', 'Muestra los sitios que enlazan a tu weblog');
@define('TOP_EXITS', 'Salidas');
@define('SHOWS_TOP_EXIT', 'Muestra los enlaces de salida ms frecuentes desde tu weblog');
@define('SYNDICATION', 'Sindicacin');
@define('SHOWS_RSS_BLAHBLAH', 'Muestra los enlaces RSS de sindicacin');
@define('ADVERTISES_BLAHBLAH', 'Informa del programa en el que se basa tu weblog');
@define('HTML_NUGGET', 'Fragmento de HTML');
@define('HOLDS_A_BLAHBLAH', 'Presenta un fragmento de HTML en la barra lateral');
@define('TITLE_FOR_NUGGET', 'Ttulo para el fragmento de HTML');
@define('THE_NUGGET', 'Fragmento de HTML!');
@define('SYNDICATE_THIS_BLOG', 'Sindica este blog');
@define('YOU_CHOSE', 'Elige %s');
@define('IMAGE_SIZE', 'Tamao de la imagen');
@define('IMAGE_AS_A_LINK', 'Insercin de imagen');
@define('POWERED_BY', 'Basado en');
@define('TRACKBACKS', 'Referencias');
@define('TRACKBACK', 'Referencia');
@define('NO_TRACKBACKS', 'No hay referencias');
@define('TOPICS_OF', 'Temas de');
@define('VIEW_FULL', 'ver completo');
@define('VIEW_TOPICS', 'ver temas');
@define('AT', 'a las');
@define('SET_AS_TEMPLATE', 'Mantenlo como plantilla');
@define('IN', 'en');
@define('EXCERPT', 'Segmento');
@define('TRACKED', 'Tracked');
@define('LINK_TO_ENTRY', 'Enlazar a la entrada');
@define('LINK_TO_REMOTE_ENTRY', 'Enlazar a una entrada remota');
@define('IP_ADDRESS', 'Direccin IP');
@define('USER', 'Usuario');
@define('THUMBNAIL_USING_OWN', 'Usando %s como su miniatura debido al escaso tamao.');
@define('THUMBNAIL_FAILED_COPY', 'Queras usar %s como tu miniatura, pero ha fallado la copia!');
@define('AUTHOR', 'Autor');
@define('LAST_UPDATED', 'ltima actualizacin');
@define('TRACKBACK_SPECIFIC', 'URI de referencia para esta entrada');
@define('DIRECT_LINK', 'Enlace directo a esta entrada');
@define('COMMENT_ADDED', 'Tu comentario ha sido aadido correctamente.');
@define('COMMENT_ADDED_CLICK', 'Pulsa %saqu para volver%s a los comentarios, y %saqu para cerrar%s esta ventana.');
@define('COMMENT_NOT_ADDED_CLICK', 'Pulsa %saqu para volver%s a los comentarios, y %saqu para cerrar%s esta ventana');
@define('COMMENTS_DISABLE', 'No permitir comentarios a esta entrada');
@define('COMMENTS_ENABLE', 'Permitir comentarios a esta entrada');
@define('COMMENTS_CLOSED', 'El autor no permite aadir comentarios a esta entrada');
@define('EMPTY_COMMENT', 'Tu comentario est vaco, por favor %svuelve%s e intntalo de nuevo');
@define('ENTRIES_FOR', 'Entradas para %s');
@define('DOCUMENT_NOT_FOUND', 'El documento %s no se encontr.');
@define('USERNAME', 'Nombre de usuario');
@define('PASSWORD', 'Contrasea');
@define('SERENDIPITY_INSTALLATION', 'Instalacin de Serendipity');
@define('LEFT', 'Izquierda');
@define('RIGHT', 'Derecha');
@define('HIDDEN', 'Oculto');
@define('REMOVE_TICKED_PLUGINS', 'Quita las extensiones seleccionadas');
@define('SAVE_CHANGES_TO_LAYOUT', 'Guarda los cambios en el diseo');
@define('COMMENTS_FROM', 'Comentarios para');
@define('ERROR', 'Error');
@define('DELETE_SURE', 'Ests seguro de que quieres eliminar #%s permanentemente?');
@define('NOT_REALLY', 'No...');
@define('DUMP_IT', 'S');
@define('RIP_ENTRY', 'Entrada #%s borrada.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Categora #%s eliminada. Los artculos antiguos han sido movidos a la categora #%s');
@define('CATEGORY_DELETED', 'Categora #%s eliminada.');
@define('INVALID_CATEGORY', 'Ninguna categora valida para borrar');
@define('CATEGORY_SAVED', 'Categora guardada');
@define('SELECT_TEMPLATE', 'Selecciona la plantilla que deseas utilizar en tu weblog');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'No se ha podido insertar las entradas!');
@define('YES', 'S');
@define('NO', 'No');
@define('USE_DEFAULT', 'Predeterminado');
@define('CHECK_N_SAVE', 'Revisa y guarda');
@define('DIRECTORY_WRITE_ERROR', 'No puedes escribir en el directorio %s. Comprueba los permisos.');
@define('DIRECTORY_CREATE_ERROR', 'El directorio %s no existe y no puede ser creado. Cralo manualmente.');
@define('DIRECTORY_RUN_CMD', ' - ejecuta <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'No se puede ejecutar %s');
@define('FILE_WRITE_ERROR', 'No se puede escribir el fichero %s.');
@define('FILE_CREATE_YOURSELF', 'Crea el fichero tu mismo o verifica los permisos');
@define('COPY_CODE_BELOW', '<br />* Tan solo copia el cdigo situado debajo y ponlo %s dentro %s del directorio:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Cambia www por el usuario que est ejecutando el servidor web (p. ej. nobody).');
@define('BROWSER_RELOAD', 'Una vez hecho esto, pulsa en tu navegador el botn "Recargar".');
@define('DIAGNOSTIC_ERROR', 'Hemos detectado algunos errores mientras se ejecutaban varias comprobaciones en la informacin que has introducido:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity no est instalado todava. Por favor <a href="%s">instlalo</a> ahora.');
@define('INCLUDE_ERROR', 'Error de Serendipity: no se puede incluir %s - saliendo.');
@define('DATABASE_ERROR', 'Error de Serendipity: no es posible conectar a la base de datos - saliendo.');
@define('CREATE_DATABASE', 'Creando la configuracin predeterminada de la base de datos...');
@define('ATTEMPT_WRITE_FILE', 'Intentando escribir el fichero %s...');
@define('WRITTEN_N_SAVED', 'Configuracin realizada y guardada');
@define('IMAGE_ALIGNMENT', 'Alineacin de imgenes');
@define('ENTER_NEW_NAME', 'Introduzca el nuevo nombre para: ');
@define('RESIZING', 'Cambiando el tamao');
@define('RESIZE_DONE', 'Terminado (las imgenes %s cambiaron de tamao).');
@define('DELETE_IMAGE_FAIL' , 'No se puede eliminar la imagen <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Eliminada la imagen miniatura llamada <b>%s</b>');
@define('FILE_NOT_FOUND', 'No es posible encontrar el fichero con nombre <b>%s</b>, es posible que lo haya borrado ya?');
@define('ABORT_NOW', 'Salir ahora');
@define('REMOTE_FILE_NOT_FOUND', 'El fichero no fue localizado en el servidor remoto, ests seguro de que la URL: <b>%s</b> es correcta?');
@define('FILE_FETCHED', '%s enlazado como: %s');
@define('FILE_UPLOADED', 'El fichero %s fue transferido correctamente: %s');
@define('WORD_OR', 'O...');
@define('SCALING_IMAGE', 'Escalando %s a %s x %s px');
@define('KEEP_PROPORTIONS', 'Mantener las proporciones');
@define('REALLY_SCALE_IMAGE', 'Realmente deseas escalar la imagen? No se podr deshacer esta accin!');
@define('TOGGLE_ALL', 'Mostrar/Ocultar todo');
@define('TOGGLE_OPTION', 'Mostrar/Ocultar');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Suscribirse a esta entrada');
@define('UNSUBSCRIBE_OK', "%s ya no est suscrito a esta entrada");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nuevo comentario en la entrada suscrita "%s"');
@define('SUBSCRIPTION_MAIL', "Hola %s,\n\nHay un nuevo comentario a la entrada \"%s\", titulada \"%s\"\nEl autor es: %s\n\nPuedes encontrar la entrada aqu: %s\n\nPuedes dejar de recibir informacin sobre esta entrada haciendo click aqu: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hola %s,\n\nHay una nueva referencia a la entrada \"%s\", titulada \"%s\"\nEl autor es: %s\n\nPuedes encontrar la entrada aqu: %s\n\nPuedes dejar de recibir informacin sobre esta entrada haciendo click aqu: %s\n");
@define('SIGNATURE', "\n-- \n%s est basado en Serendipity.\nEl mejor programa para blog ;).\nVisita <http://s9y.org> y comprubalo.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 comentarios');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Campo "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Campo "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Imagen para el feed RSS');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Anchura de la imagen');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Altura de la imagen');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC', 'Correo electrnico del webmaster, si est disponible. (djalo vaco para no mostrarlo) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'Correo electrnico del editor, si est disponible. (djalo vaco para no mostrarlo) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL de una imagen en formato GIF/JPEG/PNG, si est disponible. (dejndolo vaco se usara el smbolo de Serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'en pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'en pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Campo "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Cantidad de minutos, despus de los cuales, tu blog no ser verificado por ningn site o aplicacin externa (si lo dejas vaco no se mostrara) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Campo "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Debera el campo "pubDate" estar incluido en un canal RSS para mostrar la fecha de la ltima entrada?');
@define('CONTENT', 'Contenido');
@define('TYPE', 'Tipo');
@define('DRAFT', 'Borrador');
@define('PUBLISH', 'Publicar');
@define('PREVIEW', 'Previsualizacin');
@define('DATE', 'Fecha');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Aviso: La fecha especificada no es vlida. Debe tener el formato AAAA-MM-DD HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Muestra la lista de categoras.');
@define('ALL_AUTHORS', 'Todos los autores');
@define('CATEGORIES_TO_FETCH', 'Categoras enlazadas');
@define('CATEGORIES_TO_FETCH_DESC', 'De que autor quiere enlazar las categoras?');
@define('PAGE_BROWSE_ENTRIES', 'Pgina %s de %s, en total %s entradas');
@define('PREVIOUS_PAGE', 'pgina anterior');
@define('NEXT_PAGE', 'pgina siguiente');
@define('ALL_CATEGORIES', 'Todas las categoras');

/* TRANSLATE */
@define('WRONG_USERNAME_OR_PASSWORD', 'Usuario o contrasea errneo');
@define('HTACCESS_ERROR', 'Para verificar tu instalacin del servidor web, serendipity deber ser capaz de escribir en el fichero ".htaccess". Esto no fue posible debido a errores de permisos. Por favor, ajusta los permisos como: <br /> %s<br />y recarga esta pgina.');
@define('SIDEBAR_PLUGINS', 'Extensiones de barra lateral');
@define('EVENT_PLUGINS', 'Extensiones de eventos');
@define('SYNCING', 'Sincronizando la base de datos con el directorio de imgenes.');
@define('SYNC_DONE', 'Hecho (Sincronizadas %s imgenes).');
@define('SORT_ORDER', 'Ordenar por');
@define('SORT_ORDER_NAME', 'Nombre de fichero');
@define('SORT_ORDER_EXTENSION', 'Extensin de fichero');
@define('SORT_ORDER_SIZE', 'Tamao de fichero');
@define('SORT_ORDER_WIDTH', 'Anchura de imagen');
@define('SORT_ORDER_HEIGHT', 'Altura de imagen');
@define('SORT_ORDER_DATE', 'Fecha de transferencia');
@define('SORT_ORDER_ASC', 'Ascendente');
@define('SORT_ORDER_DESC', 'Descendente');
@define('THUMBNAIL_SHORT', 'Miniatura');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Aplicar marca a %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Inicio de la semana');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Se ha detectado una discrepancia entre tu configuracin actual que es la versin %s, y la de serendipity versin %s, necesitas actualizar! <a href="%s">Haz click aqu</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Hola y bienvenido al agente de actualizacin de Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Estoy aqu para ayudarte a actualizar tu instalacin %s de Serendipity.');
@define('SERENDIPITY_UPGRADER_WHY', 'Ests viendo este mensaje porque has instalado Serendipity %s, pero no has actualizado la instalacin de la base de datos para coincidir con esta versin');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Actualizaciones para la base de datos (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'He encontrado los siguientes ficheros .sql que se necesitan ejecutar antes de que puedas continuar usando normalmente Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Tareas especficas de la versin');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'No se ha encontrado tareas especficas de la versin');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Quieres que realice las tareas descritas?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'No, las ejecutar manualmente');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'S, por favor');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Parece que no necesitas ejecutar ninguna actualizacin');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Considera actualizado Serendipity');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Has ignorado el paso de actualizacin de Serendipity, asegrate que tu base de datos est correctamente instalada y que las funciones planeadas son ejecutadas.');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Tu instalacin de Serendipity se ha actualizado a la versin %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Puedes volver a tu blog haciendo click %saqu%s');
@define('MANAGE_USERS', 'Gestin de usuarios');
@define('CREATE_NEW_USER', 'Crear nuevo usuario');
@define('CREATE_NOT_AUTHORIZED', 'No puedes modificar usuarios con el mismo nivel que el tuyo');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'No puedes crear usuarios con un nivel mayor que el tuyo');
@define('CREATED_USER', 'Un nuevo usuario %s se ha creado');
@define('MODIFIED_USER', 'Las propiedades del usuario %s se han cambiado');
@define('USER_LEVEL', 'Nivel de usuario');
@define('DELETE_USER', 'Ests a punto de borrar al usuario #%d %s. Ests seguro? Esto no permitir mostrar las entradas escritas por l.');
@define('DELETED_USER', 'Usuario #%d %s borrado.');
@define('LIMIT_TO_NUMBER', 'Cuntos elementos deberan mostrarse?');
@define('ENTRIES_PER_PAGE', 'entradas por pgina');
@define('DIRECTORIES_AVAILABLE', 'En la lista de subdirectorios disponibles puedes hacer click en el nombre de un directorio para crear un nuevo directorio dentro de esa estructura.');
@define('ALL_DIRECTORIES', 'todos los directorios');
@define('MANAGE_DIRECTORIES', 'Gestin de directorios');
@define('DIRECTORY_CREATED', 'Directorio <strong>%s</strong> creado.');
@define('PARENT_DIRECTORY', 'Directorio superior');
@define('CONFIRM_DELETE_DIRECTORY', 'Ests seguro de que quieres eliminar todos los contenidos del directorio %s?');
@define('ERROR_NO_DIRECTORY', 'Error: Directorio %s no existe');
@define('CHECKING_DIRECTORY', 'Verificar ficheros en directorio %s');
@define('DELETING_FILE', 'Borrando fichero %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'No puedo borrar un directorio con ficheros. Marca "forzar borrado" si quieres eliminar tambin los ficheros e intntalo de nuevo. Los ficheros que existen son:');
@define('DIRECTORY_DELETE_FAILED', 'Eliminacin del directorio %s fallida. Revisa los permisos o los mensajes anteriores.');
@define('DIRECTORY_DELETE_SUCCESS', 'Directorio %s eliminado exitosamente.');
@define('SKIPPING_FILE_EXTENSION', 'Saltando fichero: falta extensin en %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Saltando fichero: %s no se puede leer.');
@define('FOUND_FILE', 'Encontrado fichero nuevo/modificado: %s.');
@define('ALREADY_SUBCATEGORY', '%s es ya una subcategora de %s.');
@define('PARENT_CATEGORY', 'Categora superior');
@define('IN_REPLY_TO', 'En respuesta a');
@define('TOP_LEVEL', 'Nivel superior');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'Permisos');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Opciones de la base de datos');
@define('INSTALL_CAT_DB_DESC', 'Introduce aqu la informacin de tu base de datos. Serendipity la necesita para funcionar');
@define('INSTALL_DBTYPE', 'Tipo');
@define('INSTALL_DBTYPE_DESC', 'El tipo de gestor de la base de datos');
@define('INSTALL_DBHOST', 'Servidor');
@define('INSTALL_DBHOST_DESC', 'El servidor donde est el gestor de la base de datos');
@define('INSTALL_DBUSER', 'Usuario');
@define('INSTALL_DBUSER_DESC', 'El usuario que conecta a la base de datos');
@define('INSTALL_DBPASS', 'Contrasea');
@define('INSTALL_DBPASS_DESC', 'La contrasea para el usuario');
@define('INSTALL_DBNAME', 'Nombre');
@define('INSTALL_DBNAME_DESC', 'El nombre de la base de datos');
@define('INSTALL_DBPREFIX', 'Prefijo');
@define('INSTALL_DBPREFIX_DESC', 'Prefijo para los nombres de las tablas, p. ej. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Rutas');
@define('INSTALL_CAT_PATHS_DESC', 'Varias rutas a ficheros y directorios esenciales. No olvides la barra final en los directorios!');
@define('INSTALL_FULLPATH', 'Ruta completa');
@define('INSTALL_FULLPATH_DESC', 'La ruta completa y absoluta a tu instalacin de serendipity');
@define('INSTALL_UPLOADPATH', 'Ruta para los ficheros transferidos');
@define('INSTALL_UPLOADPATH_DESC', 'Todos los ficheros transferidos irn aqu, relativo a  \'Ruta completa\' - normalmente \'uploads/\'');
@define('INSTALL_RELPATH', 'Ruta relativa');
@define('INSTALL_RELPATH_DESC', 'Ruta de serendipity para tu navegador, normalmente \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Ruta relativa para las plantillas');
@define('INSTALL_RELTEMPLPATH_DESC', 'Ruta al directorio que contiene tus plantillas - Relativa a la \'ruta relativa\'');
@define('INSTALL_RELUPLOADPATH', 'Ruta relativa para los ficheros transferidos');
@define('INSTALL_RELUPLOADPATH_DESC', 'Ruta de los ficheros transferidos - Relativa a la \'ruta relativa\'');
@define('INSTALL_URL', 'URL para el blog');
@define('INSTALL_URL_DESC', 'URL base de tu instalacin de serendipity');
@define('INSTALL_INDEXFILE', 'Fichero ndice');
@define('INSTALL_INDEXFILE_DESC', 'El nombre del fichero ndice de serendipity');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'Opciones generales');
@define('INSTALL_CAT_SETTINGS_DESC', 'Configura el comportamiento de Serendipity');
@define('INSTALL_USERNAME', 'Usuario administrador');
@define('INSTALL_USERNAME_DESC', 'Nombre de usuario del administrador');
@define('INSTALL_PASSWORD', 'Contrasea de administrador');
@define('INSTALL_PASSWORD_DESC', 'Contrasea del administrador');
@define('INSTALL_EMAIL', 'Correo electrnico');
@define('INSTALL_EMAIL_DESC', 'Correo electrnico del administrador');
@define('INSTALL_SENDMAIL', 'Enviar correos al administrador?');
@define('INSTALL_SENDMAIL_DESC', 'Quieres recibir un correo electrnico cuando enven comentarios a tus entradas?');
@define('INSTALL_SUBSCRIBE', 'Permitir la subscripcin de los usuarios a las entradas?');
@define('INSTALL_SUBSCRIBE_DESC', 'Permite a los usuarios subscribirse a una entrada y de ese modo recibir un correo electrnico cuando se hacen nuevos comentarios a esa entrada');
@define('INSTALL_BLOGNAME', 'Nombre del blog');
@define('INSTALL_BLOGNAME_DESC', 'El ttulo de tu blog');
@define('INSTALL_BLOGDESC', 'Descripcin del blog');
@define('INSTALL_BLOGDESC_DESC', 'Descripcin de tu blog');
@define('INSTALL_LANG', 'Idioma');
@define('INSTALL_LANG_DESC', 'Selecciona el idioma del blog');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Apariencia');
@define('INSTALL_CAT_DISPLAY_DESC', 'Configura el aspecto general de Serendipity');
@define('INSTALL_WYSIWYG', 'Usar editor WYSIWYG');
@define('INSTALL_WYSIWYG_DESC', 'Quieres usar el editor WYSIWYG? (Funciona con IE5+, parcialmente con Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Forzar compatibilidad XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'Quieres forzar la compatibilidad XHTML 1.1? (puede causar problemas con navegadores ms antiguos que la 4 generacin)');
@define('INSTALL_POPUP', 'Activar el uso de ventanas emergentes');
@define('INSTALL_POPUP_DESC', 'Quieres que el blog use una ventana emergente para los comentarios, referencias, etc.?');
@define('INSTALL_EMBED', 'Est Serendipity insertado en otra web?');
@define('INSTALL_EMBED_DESC', 'Si quieres insertar Serendipity dentro de otra pgina, ajusta a "s" para eliminar cualquier cabecera y slo mostrar los contenidos. Puedes hacer uso de la opcin indexFile y usar una clase donde pongas las cabeceras normales de tu pgina web. Lee el fichero README para ms informacin!');
@define('INSTALL_TOP_AS_LINKS', 'Mostrar Salidas/Sitios asociados como enlaces?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"no": Las Salidas y los Sitios asociados se muestran como texto sin formato para prevenir spam en google. "yes": Las Salidas y Sitios asociando se muestran como enlaces. "default": Usar el valor de la configuracin global (recomendado).');
@define('INSTALL_BLOCKREF', 'Sitios asociados bloqueados');
@define('INSTALL_BLOCKREF_DESC', 'Hay algn servidor que no quieras que se muestre en la lista de Sitios asociados? Separa la lista de nombres de dominio con \';\' y advierte que se bloquea por coincidencias en subcadenas!');
@define('INSTALL_REWRITE', 'Reescritura de URL');
@define('INSTALL_REWRITE_DESC', 'Selecciona la regla que quieres usar para generar URL. Activando estas reglas har URL bonitas para tu blog y lo har ms indexable para los robots como google. El servidor web necesita tener o mod_rewrite o "AllowOverride All" para el directorio de serendipity. El valor predeterminado es autodetectado');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Opciones para la conversin de imgenes');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Informacin sobre cmo debera serendipity manejar imgenes');
@define('INSTALL_IMAGEMAGICK', 'Usar ImageMagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Tienes ImageMagick instalado y quieres usarlo para redimensionar imgenes?');
@define('INSTALL_IMAGEMAGICKPATH', 'Ruta hasta el programa convert');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Ruta completa y nombre del programa convert de ImageMagick');
@define('INSTALL_THUMBSUFFIX', 'Sufijo de la miniatura');
@define('INSTALL_THUMBSUFFIX_DESC', 'Las miniaturas se crearn con el siguiente formato: original.[sufijo].ext');
@define('INSTALL_THUMBWIDTH', 'Dimensiones de las miniaturas');
@define('INSTALL_THUMBWIDTH_DESC', 'Anchura mxima esttica de las miniaturas auto-generadas');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Datos personales');
@define('USERCONF_CAT_PERSONAL_DESC', 'Cambia los datos personales');
@define('USERCONF_USERNAME', 'Nombre de usuario');
@define('USERCONF_USERNAME_DESC', 'El nombre de usuario que se usa para conectar al blog');
@define('USERCONF_PASSWORD', 'Contrasea');
@define('USERCONF_PASSWORD_DESC', 'La contrasea que se usar para conectar al blog');
@define('USERCONF_EMAIL', 'Correo electrnico');
@define('USERCONF_EMAIL_DESC', 'La direccin de correo electrnico personal');
@define('USERCONF_SENDCOMMENTS', 'Enviar avisos de comentarios?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Desea que se le enven notificaciones mediante correo electrnico cuando se reciban comentarios a las entradas?');
@define('USERCONF_SENDTRACKBACKS', 'Enviar avisos de referencias?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Desea que se le enven notificaciones mediante correo electrnico cuando se hagan referencias a las entradas?');
@define('USERCONF_ALLOWPUBLISH', 'Derechos: Publicar entradas?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'El usuario puede publicar entradas?');
@define('XML_IMAGE_TO_DISPLAY', 'Botn XML');
@define('XML_IMAGE_TO_DISPLAY_DESC','Enlaces a feeds XML se mostrarn con esta imagen. Djalo vaco para el valor predeterminado, introduce \'none\' para desactivar.');
@define('ENTRY_SAVED', 'Tu entrada ha sido guardada');
@define('SUCCESS', 'xito');

@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');

@define('POWERED_BY_SHOW_TEXT', 'Mostrar "Serendipity" como texto');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Mostrar "Serendipity Weblog" como texto');
@define('POWERED_BY_SHOW_IMAGE', 'Mostrar "Serendipity" con una imagen');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Mostrar el logotipo de Serendipity');

/* TRANSLATE */
@define('SETTINGS_SAVED_AT', 'La nueva configuracin se ha guardado a la hora %s');
@define('PLUGIN_ITEM_DISPLAY', 'Dnde debera mostrarse el elemento?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Slo en la entrada extendida');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Slo en la entrada general');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Siempre');
@define('RSS_IMPORT_CATEGORY', 'Usa esta categora para las entradas importadas que no coincidan');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Ocurri un error desconocido, fichero no importado. Quizs el tamao del fichero es mayor que el tamao mximo permitido por tu instalacin. Verifica con tu ISP o edita tu fichero php.ini para permitir transferir ficheros de tamao ms grande.');
@define('COMMENTS_WILL_BE_MODERATED', 'Los comentarios enviados sern sometidos a moderacin antes de ser mostrados.');
@define('YOU_HAVE_THESE_OPTIONS', 'Tienes disponibles las siguientes opciones:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Aviso: Este comentario necesita aprobacin antes de que se muestre');
@define('DELETE_COMMENT', 'Borrar comentario');
@define('APPROVE_COMMENT', 'Aprobar comentario');
@define('REQUIRES_REVIEW', 'Requiere revisin');
@define('COMMENT_APPROVED', 'El comentario #%s ha sido aprobado exitosamente');
@define('COMMENT_DELETED', 'El comentario #%s ha sido borrado exitosamente');
@define('VIEW', 'Ver');
@define('COMMENT_ALREADY_APPROVED', 'El comentario #%s ya parece haber sido aprobado');
@define('COMMENT_EDITED', 'El comentario seleccionado ha sido editado');
@define('HIDE', 'Ocultar');
@define('VIEW_EXTENDED_ENTRY', 'Continua leyendo "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Este enlace no es para hacer click en l. Contiene la URI de referencia para esta entrada. Puedes usar esta URI para enviar "ping-" y "trackbacks" desde tu propio blog a esta entrada. Para copiar el enlace, haz click con el botn derecho y selecciona "Copy Shortcut" en Internet Explorer o "Copy Link Location" en Mozilla.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Aviso: Esta referencia necesita aprobacin antes de que se muestre');
@define('DELETE_TRACKBACK', 'Borrar referencia');
@define('APPROVE_TRACKBACK', 'Aprobar referencia');
@define('TRACKBACK_APPROVED', 'La referencia #%s ha sido aprobada exitosamente');
@define('TRACKBACK_DELETED', 'La referencia #%s ha sido borrado exitosamente');
@define('COMMENTS_MODERATE', 'Comentarios y referencias a esta entrada requieren moderacin');
@define('PLUGIN_SUPERUSER_HTTPS', 'Usar https para conectar');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Hacer que el enlace para conectar apunte a una conexin https. Tu servidor web necesita soporte para esto!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Poder hacer click en los enlaces externos?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"no": Enlaces externos no verificados (Top Salidas, Top Sitios asociados, Comentarios de usuarios) no se muestran/se muestran como texto sin formato donde se pueda para prevenir spam de google (recomendado). "s": Enlaces externos no verificados se muestran como enlaces. Puede ser modificado en la configuracin de la extensin de la barra lateral!');
@define('PAGE_BROWSE_COMMENTS', 'Pgina %s de %s, total %s comentarios');
@define('FILTERS', 'Filtros');
@define('FIND_ENTRIES', 'Encontrar entradas');
@define('FIND_COMMENTS', 'Encontrar comentarios');
@define('FIND_MEDIA', 'Encontrar medios');
@define('FILTER_DIRECTORY', 'Directorio');
@define('SORT_BY', 'Ordenacin');
@define('TRACKBACK_COULD_NOT_CONNECT', 'No se ha enviado la referencia: No se pudo establecer conexin con %s en el puerto %d');
@define('MEDIA', 'Medios');
@define('MEDIA_LIBRARY', 'Biblioteca de medios');
@define('ADD_MEDIA', 'Aadir medio');
@define('ENTER_MEDIA_URL', 'Introduce una URL para obtener el fichero:');
@define('ENTER_MEDIA_UPLOAD', 'Selecciona el fichero que quieres transferir:');
@define('SAVE_FILE_AS', 'Guardar el fichero como:');
@define('STORE_IN_DIRECTORY', 'Almacenar dentro del siguiente directorio: ');
@define('MEDIA_RENAME', 'Renombrar este fichero');
@define('IMAGE_RESIZE', 'Redimensionar esta imagen');
@define('MEDIA_DELETE', 'Borrar este fichero');
@define('FILES_PER_PAGE', 'Ficheros por pgina');
@define('CLICK_FILE_TO_INSERT', 'Haz click en el fichero que quieres insertar:');
@define('SELECT_FILE', 'Selecciona el fichero a insertar');
@define('MEDIA_FULLSIZE', 'Tamao real');
@define('CALENDAR_BOW_DESC', 'El da de la semana que debe considerarse como principio de semana. El predeterminado es el lunes');
@define('SUPERUSER', 'Administracin del Blog');
@define('ALLOWS_YOU_BLAHBLAH', 'Muestra un enlace en la barra lateral para acceder a la administracin de tu blog');
@define('CALENDAR', 'Calendario');
@define('SUPERUSER_OPEN_ADMIN', 'Abre administracin');
@define('SUPERUSER_OPEN_LOGIN', 'Abre ventana de conexin');
@define('INVERT_SELECTIONS', 'Invertir selecciones');
@define('COMMENTS_DELETE_CONFIRM', 'Ests seguro que deseas eliminar los comentarios seleccionados?');
@define('COMMENT_DELETE_CONFIRM', 'Ests seguro que deseas eliminar el comentario #%d, escrito por %s?');
@define('DELETE_SELECTED_COMMENTS', 'Borrar comentarios seleccionados');
@define('VIEW_COMMENT', 'Ver comentario');
@define('VIEW_ENTRY', 'Ver entrada');
@define('DELETE_FILE', 'Borrado el fichero llamado <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Ests a punto de borrar <b>%s</b><br />Si ests usando este fichero en alguna de tus entradas, esto causar enlaces o imgenes rotos<br />Ests seguro de que quieres seguir?<br /><br />');
@define('TRACKBACK_SENDING', 'Enviando referencia a la URI %s...');
@define('TRACKBACK_SENT', 'Referencia exitosa');
@define('TRACKBACK_FAILED', 'Referencia fallida: %s');
@define('TRACKBACK_NOT_FOUND', 'No encontrada URI de referencia.');
@define('TRACKBACK_URI_MISMATCH', 'La referencia autodetectada no coincide con nuestra URI destino.');
@define('TRACKBACK_CHECKING', 'Comprobando <u>%s</u> para posibles referencias...');
@define('TRACKBACK_NO_DATA', 'Destino no contena datos');
@define('TRACKBACK_SIZE', 'La URI de destino excedi el tamao de fichero mximo de %s bytes.');
@define('VIEWMODE_THREADED', 'Cambiar a vista por hilos');
@define('COMMENTS_VIEWMODE_THREADED', 'Hilos');
@define('COMMENTS_VIEWMODE_LINEAR', 'Plano');
@define('DISPLAY_COMMENTS_AS', 'Mostrar comentarios como');
@define('LOGIN', 'Conectar');
@define('AUTOMATIC_LOGIN', 'Guardar informacin');
@define('DO_MARKUP', 'Realizar transformaciones marcas');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Formato de fecha');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'El formato de fecha de la entrada actual, usa las variables strftime() de PHP. (Predeterminado: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Incapaz de abrir el fichero plantilla, por favor actualiza serendipity!');
@define('ADVANCED_OPTIONS', 'Opciones avanzadas');
@define('EDIT_ENTRY', 'Editar entrada');
@define('ADD_MEDIA_BLAHBLAH', '<b>Aade un fichero a tu coleccin de medios:</b><p>Desde aqu puedes transferir un fichero de medios o puedes decirme que los coja de algn lugar de la web! Si no tienes una imagen apropiada, <a href="http://images.google.com" target="_blank">busca imgenes en google</a> que vaya con tu forma de pensar, los resultados son tiles y divertidos a veces :)</p><p><b>Selecciona el mtodo:</b></p><br/>');
@define('COMMENTS_FILTER_SHOW', 'Mostrar');
@define('COMMENTS_FILTER_ALL', 'Todo');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Slo lo aprobado');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Pendiente de aprobacin');
@define('RSS_IMPORT_BODYONLY', 'Coloca todo el texto importado en el "cuerpo" y no lo separes en la seccin "entrada extendida".');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Mostrar los artculos completos con la entrada extendida dentro del feed RSS');
@define('MT_DATA_FILE', 'fichero de datos de Movable Type');
@define('FORCE', 'Forzar');
@define('CREATE_AUTHOR', 'Crear autor \'%s\'.');
@define('CREATE_CATEGORY', 'Crear categora \'%s\'.');
@define('MYSQL_REQUIRED', 'Debes tener la extensin MySQL para poder llevar a cabo esta accin.');
@define('COULDNT_CONNECT', 'No se puede conectar al gestor de base de datos MySQL: %s.');
@define('COULDNT_SELECT_DB', 'No se puede seleccionar la base de datos: %s.');
@define('COULDNT_SELECT_USER_INFO', 'No se puede seleccionar la informacin del usuario: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'No se puede seleccionar la informacin de la categora: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'No se puede seleccionar la informacin de la entrada: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'No se puede seleccionar la informacin del comentario: %s.');
@define('WEEK', 'Semana');
@define('WEEKS', 'Semanas');
@define('MONTHS', 'Meses');
@define('DAYS', 'Das');
@define('ARCHIVE_FREQUENCY', 'Frecuencia de los elementos del Calendario');
@define('ARCHIVE_FREQUENCY_DESC', 'El intervalo temporal a usar entre cada elemento en la lista');
@define('ARCHIVE_COUNT', 'Nmero de elementos en la lista');
@define('ARCHIVE_COUNT_DESC', 'El nmero total de meses, semanas o das que se visualizan');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Abajo est la lista de las extensiones instaladas');
@define('SIDEBAR_PLUGIN', 'extensin de barra lateral');
@define('EVENT_PLUGIN', 'extensin de evento');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Click aqu para instalar una nueva %s');
@define('VERSION', 'versin');
@define('INSTALL', 'Instalar');
@define('ALREADY_INSTALLED', 'Ya est instalado');
@define('SELECT_A_PLUGIN_TO_ADD', 'Selecciona la extensin que quieras instalar');
@define('INSTALL_OFFSET', 'Diferencia horaria del servidor');
@define('STICKY_POSTINGS', 'Entradas permanentes');
@define('INSTALL_FETCHLIMIT', 'Entradas a mostrar en la pgina principal');
@define('INSTALL_FETCHLIMIT_DESC', 'Nmero de entradas a mostrar en la pgina principal');
@define('IMPORT_ENTRIES', 'Importar entradas');
@define('EXPORT_ENTRIES', 'Exportar entradas');
@define('IMPORT_WELCOME', 'Bienvenido a la utilidad de importacin de Serendipity');
@define('IMPORT_WHAT_CAN', 'Aqu puedes importar entradas producidas en otros programas de weblog');
@define('IMPORT_SELECT', 'Por favor selecciona el software desde el que quieres importar');
@define('IMPORT_PLEASE_ENTER', 'Por favor introduce los datos como se requiere debajo');
@define('IMPORT_NOW', 'Importar ahora!');
@define('IMPORT_STARTING', 'Iniciando procedimiento de importacin...');
@define('IMPORT_FAILED', 'Importacin fallida');
@define('IMPORT_DONE', 'Importacin completada con xito');
@define('IMPORT_WEBLOG_APP', 'Aplicacin weblog');
@define('EXPORT_FEED', 'Exportar la sindicacin RSS completa');
@define('STATUS', 'Estado despus de importar');
@define('IMPORT_GENERIC_RSS', 'Importar RSS genrico');
@define('ACTIVATE_AUTODISCOVERY', 'Enviar referencias a los enlaces encontrados en la entrada');
@define('WELCOME_TO_ADMIN', 'Bienvenido a la Suite de Administracin de Serendipity.');
@define('PLEASE_ENTER_CREDENTIALS', 'Por favor introduce tus credenciales abajo.');
@define('ADMIN_FOOTER_POWERED_BY', 'Basado en Serendipity %s y PHP %s');
@define('INSTALL_USEGZIP', 'Usar pginas comprimidas con gzip');
@define('INSTALL_USEGZIP_DESC', 'Para acelerar el envo de pginas, se pueden comprimir las pginas que se envan al visitante, si su navegador lo admite. Esto es lo recomendado');
@define('INSTALL_SHOWFUTURE', 'Mostrar entradas futuras');
@define('INSTALL_SHOWFUTURE_DESC', 'Si se activa, mostrar todas las entradas con fecha futura en tu blog. La accin predeterminada es no mostrar esas entradas y slo hacerlo cuando llegue la fecha de publicacin.');
@define('INSTALL_DBPERSISTENT', 'Usar conexiones persistentes');
@define('INSTALL_DBPERSISTENT_DESC', 'Activar el uso de conexiones persistentes a la base de datos, lee ms en <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">here</a>. Normalmente no se recomienda');
@define('NO_IMAGES_FOUND', 'No se encontraron imgenes');
@define('PERSONAL_SETTINGS', 'Configuracin personal');
@define('REFERER', 'Referer');
@define('NOT_FOUND', 'No encontrado');
@define('NOT_WRITABLE', 'No se puede escribir');
@define('WRITABLE', 'Se puede escribir');
@define('PROBLEM_DIAGNOSTIC', 'Debido a los problemas encontrados, no puedes continuar con la instalacin sin antes solucionar los errores sealados');
@define('SELECT_INSTALLATION_TYPE', 'Selecciona qu tipo de instalacin quieres usar');
@define('WELCOME_TO_INSTALLATION', 'Bienvenido a la Instalacin de Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Primero determinaremos tu configuracin actual e intentaremos diagnosticar cualquier problema de compatibilidad');
@define('ERRORS_ARE_DISPLAYED_IN', 'Los errores se muestran en %s, las recomendaciones en %s y lo bien configurado en %s');
@define('RED', 'rojo');
@define('YELLOW', 'amarillo');
@define('GREEN', 'verde');
@define('PRE_INSTALLATION_REPORT', 'Informe de preinstalacin de Serendipity v%s');
@define('RECOMMENDED', 'Recomendado');
@define('ACTUAL', 'Actual');
@define('PHPINI_CONFIGURATION', 'Configuracin de php.ini');
@define('PHP_INSTALLATION', 'Instalacin de PHP');
@define('THEY_DO', 'existen');
@define('THEY_DONT', 'no existen');
@define('SIMPLE_INSTALLATION', 'Instalacin simple');
@define('EXPERT_INSTALLATION', 'Instalacin avanzada');
@define('COMPLETE_INSTALLATION', 'Completar instalacin');
@define('WONT_INSTALL_DB_AGAIN', 'no se instalar de nuevo la base de datos');
@define('CHECK_DATABASE_EXISTS', 'Comprobando si la base de datos y las tablas ya existen');
@define('CREATING_PRIMARY_AUTHOR', 'Creando el autor principal \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Configurando la plantilla predeterminada');
@define('INSTALLING_DEFAULT_PLUGINS', 'Instalando extensiones predeterminadas');
@define('SERENDIPITY_INSTALLED', 'Serendipity se ha instalado exitosamente');
@define('VISIT_BLOG_HERE', 'Visita tu nuevo blog aqu');
@define('THANK_YOU_FOR_CHOOSING', 'Gracias por elegir Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Se detect un error en la instalacin');
@define('OPERATING_SYSTEM', 'Sistema operativo');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('TEMPLATE_SET', '\'%s\' ha sido configurada como tu plantilla activa');
@define('SEARCH_ERROR', 'La funcin de bsqueda no funcion como se esperaba. Aviso para el administrador de este blog: esto ocurre porque faltan claves de ndice en tu base de datos. En sistemas MySQL tu cuenta de usuario en la base de datos necesita tener privilegios para ejecutar esta consulta: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> El error especfico devuelto por la base de datos fue: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Editando "%s"');
@define('CATEGORY_REMAINING', 'Borra esta categora y mueve sus entradas a esta categora');
@define('CATEGORY_INDEX', 'Abajo se muestra una lista de las categoras disponibles para tus entradas');
@define('NO_CATEGORIES', 'No hay categoras');
@define('RESET_DATE', 'Volver a poner la fecha');
@define('RESET_DATE_DESC', 'Click aqu para poner la fecha actual');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Los permisos se pueden modificar ejecutando: `<em>%s</em>` sobre el directorio que ha fallado, lo puedes hacer desde la lnea de comandos o usando un programa FTP');
@define('WARNING_TEMPLATE_DEPRECATED', 'Aviso: Tu plantilla actual est usando un mtodo obsoleto de plantillas, actualzala si es posible');
@define('ENTRY_PUBLISHED_FUTURE', 'Esta entrada no se ha publicado todava.');
@define('ENTRIES_BY', 'Entradas por %s');
@define('PREVIOUS', 'Anterior');
@define('NEXT', 'Siguiente');
@define('APPROVE', 'Aprobar');
@define('DO_MARKUP_DESCRIPTION', 'Aplicar transformaciones de marcas al texto (caras, marcas abreviadas como *. /, _, ...). Desactivando esto preservar cualquier cdigo HTML en el texto.');
@define('CATEGORY_ALREADY_EXIST', 'Una categora con el nombre "%s" ya existe');
@define('IMPORT_NOTES', 'Nota:');
@define('ERROR_FILE_FORBIDDEN', 'No te est permitido transferir ficheros con contenido activo');
@define('ADMIN', 'Administracin');
@define('ADMIN_FRONTPAGE', 'Pgina principal');
@define('QUOTE', 'Cita');
@define('IFRAME_SAVE', 'Serendipity est guardando tu entrada, creando referencias y llevando a cabo las posibles llamadas XML-RPC. Esto puede durar un tiempo..');
@define('IFRAME_SAVE_DRAFT', 'Se ha guardado un borrador de esta entrada');
@define('IFRAME_PREVIEW', 'Serendipity est creando la vista previa de tu entrada...');
@define('IFRAME_WARNING', 'Tu navegador no admite el concepto de "iframes". Por favor, edita tu fichero serendipity_config.inc.php y ajusta la variable $serendipity[\'use_iframe\'] a FALSE.');
@define('NONE', 'ninguno');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Configuracin predeterminada para las nuevas entradas');
@define('UPGRADE', 'Actualizar');
@define('UPGRADE_TO_VERSION', 'Actualizar a la versin %s');
@define('DELETE_DIRECTORY', 'Borrar directorio');
@define('DELETE_DIRECTORY_DESC', 'Ests a punto de borrar los contenidos de un directorio que contiene ficheros de medios, posiblemente ficheros utilizados en algunas de tus entradas.');
@define('FORCE_DELETE', 'Borrar TODOS los ficheros de este directorio, incluyendo aquellos desconocidos para Serendipity');
@define('CREATE_DIRECTORY', 'Crear directorio');
@define('CREATE_NEW_DIRECTORY', 'Crear nuevo directorio');
@define('CREATE_DIRECTORY_DESC', 'Aqu puedes crear un nuevo directorio para almacenar ficheros de medios. Escoge el nombre del nuevo directorio y selecciona un directorio superior (opcional) donde ponerlo.');
@define('BASE_DIRECTORY', 'Directorio base');
@define('USERLEVEL_EDITOR_DESC', 'Editor estndar');
@define('USERLEVEL_CHIEF_DESC', 'Editor jefe');
@define('USERLEVEL_ADMIN_DESC', 'Administrador');
@define('USERCONF_USERLEVEL', 'Nivel de acceso');
@define('USERCONF_USERLEVEL_DESC', 'Este nivel se usa para determinar que clase de acceso al blog tiene el usuario');
@define('USER_SELF_INFO', 'Conectado como %s (%s)');
@define('ADMIN_ENTRIES', 'Entradas');
@define('RECHECK_INSTALLATION', 'Volver a comprobar la instalacin');
@define('IMAGICK_EXEC_ERROR', 'Incapaz de ejecutar: "%s", error: %s, variable devuelta: %d');
@define('INSTALL_OFFSET_DESC', 'Introduce la diferencia de horas entre la fecha de tu servidor web (actual: %clock%) y la zona horaria deseada');
@define('UNMET_REQUIREMENTS', 'Requisitos no alcanzados: %s');
@define('CHARSET', 'Juego de caracteres');
@define('AUTOLANG', 'Usar el lenguaje del navegador del visitante como predeterminado');
@define('AUTOLANG_DESC', 'Si est activado, se usar la configuracin de lenguaje del navegador del visitante para determinar el lenguaje predeterminado de tu entrada as como de la interfaz.');
@define('INSTALL_AUTODETECT_URL', 'Autodetectar HTTP-Host usado');
@define('INSTALL_AUTODETECT_URL_DESC', 'Si se configura como "S", Serendipity asegurar que el nombre de Host HTTP que us por tu visitante para acceder al blog se usa como la URL base. Activando esto te permitir usar varios nombres de dominio para tu blog, y usar ese dominio para todos los enlaces que siga el usuario.');
@define('CONVERT_HTMLENTITIES', 'Intentar autoconvertir las entidades HTML?');
@define('EMPTY_SETTING', 'No especificaste un valor vlido para "%s"!');
@define('USERCONF_REALNAME', 'Nombre real');
@define('USERCONF_REALNAME_DESC', 'El nombre completo del autor. Este es el nombre que vern los lectores.');
@define('HOTLINK_DONE', 'Fichero como recurso externo enlazado.<br />Hecho.');
@define('ENTER_MEDIA_URL_METHOD', 'Mtodo de obtencin:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Enlazar recursos externos te permite usar imgenes externas sin almacenarlas localmente. Si escoges esta opcin, asegrate de poseer los permisos para hacerlo en el servidor externo o bien el servidor es tuyo.');
@define('MEDIA_HOTLINKED', 'enlazado externamente');
@define('FETCH_METHOD_IMAGE', 'Descargar imagen a tu servidor');
@define('FETCH_METHOD_HOTLINK', 'Enlazar externamente al servidor');
@define('DELETE_HOTLINK_FILE', 'Borrado el recurso enlazado externamente con el nombre <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Mostrar la direccin de correo?');
@define('IMAGE_MORE_INPUT', 'Aadir ms imgenes');
@define('BACKEND_TITLE', 'Informacin adicional en la pantalla de configuracin de extensiones');
//mine
@define('BACKEND_TITLE_FOR_NUGGET', 'Aqu puedes definir una cadena personalizada que se mostrar en la ventana de configuracin de extensiones junto con la descripcin de la extensin fragmento de HTML. Si tienes varios fragmentos HTML sin ttulo, esto te ayudar a diferenciarlos.');
@define('CATEGORIES_ALLOW_SELECT', 'Permitir a los visitantes mostrar mltiples categoras a la vez?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Si activas esta opcin aparecer un checkbox a lado de cada categora en la extensin de la barra lateral. Los usuarios podrn marcar las categoras que deseen y luego ver las entradas pertenecientes a estas.');
@define('PAGE_BROWSE_PLUGINS', 'Pgina %s de %s, totalizando %s extensiones.');
@define('INSTALL_CAT_PERMALINKS', 'Enlaces permanentes');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Define varios patrones URL para definir enlaces permanentes en tu blog. Es recomendado que utilices los valores por defecto; sino, debes tratar de utilizar el valor %id% donde sea posible para evitar que Serendipity busque en la base de datos la URL.');
@define('INSTALL_PERMALINK', 'Estructura URL de los enlaces permanentes');
@define('INSTALL_PERMALINK_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas sean accesibles. Puedes utilizar las variables %id%, %title%, %day%, %month%, %year%  y cualquier otro caracter.');
@define('INSTALL_PERMALINK_AUTHOR', 'Estructura URL de los enlaces permanentes al autor');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierto autor sean accesibles. Puedes utilizar las variables %id%, %realname%, %username%, %email% y cualquier otro caracter.');
@define('INSTALL_PERMALINK_CATEGORY', 'Estructura URL de los enlaces permanentes a categoras');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierta categora sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Estructura URL de los enlaces permanentes a la sindicacin RSS de las categoras');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las sindicaciones RSS de ciertas categoras sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Ruta a los archivos');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Ruta para archivar');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Ruta a las categoras');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Ruta para desinscribirse de los comentarios'); //check later
@define('INSTALL_PERMALINK_DELETEPATH', 'Ruta para eliminar comentarios');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Ruta para aprobar comentarios');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Ruta a las sindicaciones RSS');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Ruta a extensin');
@define('INSTALL_PERMALINK_ADMINPATH', 'Ruta a admin');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Ruta para buscar');
@define('INSTALL_CAL', 'Tipo de calendario');
@define('INSTALL_CAL_DESC', 'Elige tu formato de calendario');
@define('REPLY', 'Responder');
@define('USERCONF_GROUPS', 'Membresas');
@define('USERCONF_GROUPS_DESC', 'Este usuario es miembro de los siguientes grupos. Mltiples membresas son posibles.');
@define('MANAGE_GROUPS', 'Administracin de grupos');
@define('DELETED_GROUP', 'Grupo #%d %s eliminado.');
@define('CREATED_GROUP', 'Un nuevo grupo %s ha sido creado');
@define('MODIFIED_GROUP', 'Las propiedades del grupo %s han sido modificado');
@define('GROUP', 'Grupo');
@define('CREATE_NEW_GROUP', 'Crear nuevo grupo');
@define('DELETE_GROUP', 'Ests apunto de eliminar el grupo #%d %s. Ests seguro?');
@define('USERLEVEL_OBSOLETE', 'AVISO: El atributo de nivel de acceso es ahora utilizado slo con propsitos de compatibilidad con versiones anteriores de extensiones y autorizacin. Los privilegios de usuarios son ahora manejados por membresas!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'ID FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'El ID del feed que deseas publicar');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'Imagen FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Nombre de la imagen a mostrar (djalo en blanco para un contador), localizada en feedburner.com, ej: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'Ttulo FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Ttulo (si hay) a mostrar al lado de la imagen');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'Texto de la imagen FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Texto (si hay) a mostrar al colocar el puntero del ratn sobre la imagen');
@define('SEARCH_TOO_SHORT', 'El patrn de bsqueda debe ser mayor a 3 caracteres. Puedes aadirle * a palabras ms cortas, como: s9y* para poder hacer bsquedas ms cortas.');
@define('INSTALL_DBPORT', 'Puerto de la base de datos');
@define('INSTALL_DBPORT_DESC', 'El puerto utilizado para conectarse con el servidor de tu base de datos');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Interfaz: Servicios externos');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Interfaz: Caractersticas');

@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Interfaz: Full Mods');//Translate

@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Interfaz: Vistas');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Interfaz: Relacionado a la entrada'); //Frontend: Entry Related
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Motor: Editor');//Backend, better translation?
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Motor: Manejo de usuarios');//Backend, better translation?
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Motor: Meta informacin');//Backend, better translation?
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Motor: Plantillas');//Backend, better translation?
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Motor: Caractersticas');//Backend, better translation?
@define('PLUGIN_GROUP_IMAGES', 'Imgenes');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');

@define('PLUGIN_GROUP_MARKUP', 'Markup');//Translate

@define('PLUGIN_GROUP_STATISTICS', 'Estadsticas');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Configuracin de acceso personal');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Modificar los niveles de usuario');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Modificar "prohibir crear entradas"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Modificar los permisos de publicar entradas');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Configuracin del sistema de acceso');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Configuracin de acceso centralizado al blog');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrar entradas');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrar entradas de otros usuarios');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Importar entradas');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrar categoras');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrar categoras de otros usuarios');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Eliminar categoras');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrar usuarios');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Eliminar usuarios');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Modificar nivel de usuario');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrar otros usuarios que pertenecen a tu mismo grupo(s)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrar otros usuarios que no pertenece a tu mismo grupo(s)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Crear nuevos usuarios');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrar grupo de usuarios');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrar extensiones');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrar extensiones de otros usuarios');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrar medios');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrar directorios de medios');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Aadir nuevo fichero de medios');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Eliminar fichero de medios');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrar ficheros de medios de otros usuarios');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Ver ficheros de medios');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Sincronizar miniaturas');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrar comentarios');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrar plantillas');
@define('INSTALL_BLOG_EMAIL', 'Correo electrnico del Blog');
@define('INSTALL_BLOG_EMAIL_DESC', 'Aqu se configura la direccin de correo electrnico que se utiliza como "De:" en los correos salientes. Asegrate de definir esta variable con una direccin que sea reconocida por el servidor de correo de tu hosts - muchos servidores de correo rechazan los mensajes que tienen una direccin "De:" desconocida.');
@define('CATEGORIES_PARENT_BASE', 'Slo mostrar categoras bajo...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Puedes elegir una categora padre de manera que slo las categoras hijos sean mostradas.');
@define('CATEGORIES_HIDE_PARALLEL', 'Ocultar las categoras que no son parte del rbol de categoras');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Si deseas ocultar categoras que son parte de otro rbol de directorios, necesitas activar esta opcin. Esta caracterstica tiene ms sentido si se utiliza junto con un multi-blog y la extensin de "Propiedades/plantillas de categoras".');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Ver ficheros de medios de otros usuario');
@define('CHARSET_NATIVE', 'Nativo');
@define('INSTALL_CHARSET', 'Seleccin del juego de caracteres');
@define('INSTALL_CHARSET_DESC', 'Aqu puedes activar la codificacin de caracteres UTF-8 o nativo (ISO, EUC, ...). Algunos lenguajes slo tienen traducciones UTF-8 as que colocar la codificacin en "nativo" no tendr efectos. Se sugiere UTF-8 en nuevas instalaciones. No alteres la configuracin si ya has hecho entradas con caracteres especiales ya que podra conllevar una corrupcin de caracteres. Asegrate de leer ms sobre este problema en  http://www.s9y.org/index.php?node=46.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Habilitar API de conexiones de las extensiones');
@define('CALENDAR_EXTEVENT_DESC', 'Si est habilitada, esta opcin permite que las extensiones se conecten con el calendario para mostrar sus eventos resaltados. Utilzalo slo si has instalado extensiones que lo necesitan, de otra forma slo disminuye el desempeo.');


/*
Melvin TODO [20060128]: Reorganize (perhaps) next constants in the order they belong
Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
*/
@define('XMLRPC_NO_LONGER_BUNDLED', 'El API de la interfase XML-RPC en Serendipity no est incluido debido a problemas de seguridad que hay en curso con este API, adems del hecho que no es usada con mucha frecuencia. De esta forma, usted necesita instalar la extensin XML-RPC para utilizar API de XML-RPC. Las URL que usa en sus aplicaciones NO cambiarn y tan pronto como instale la extensin podr usar el API.');
@define('PERM_READ', 'Permiso de lectura');
@define('PERM_WRITE', 'Permiso de escritura');
@define('PERM_DENIED', 'Permiso denegado.');
@define('INSTALL_ACL', 'Aplicar permisos de lectura por categoras');
@define('INSTALL_ACL_DESC', 'Cuando se activa, son aplicados los permisos para grupos de usuarios que estn configurados cuando los usuarios registrados vean el Blog. Cuando se desactiva, los permisos de lectura de las categoras NO son aplicadas, con el efecto positivo que el Blog carga un poco ms rpido. Si no necesitas permisos de lectura para mltiples usuarios, deshabilita esta opcin.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Sintaxis errnea en la configuracin de la opcin "%s". Se requiere contenido de tipo "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Contrasea actual');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Si cambias la contrasea en el campo de arriba, debes escribir la contrasea actual en este campo.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'No especificaste correctamente la contrasea actual, por lo tanto no estas autorizado para establecer una nueva. Tus cambios no fueron guardados.');
@define('ERROR_XSRF', 'Tu navegador no envi una cadena vlida de HTTP-Referrer. Esto puede deberse a una mala configuracin del navegador/proxy o por un "Cross Site Request Forgery (XSRF)" dirigido a ti. La accin solicitada no pudo ser completada.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Aqu puedes definir la estructura relativa de URLs comenzando por tu URL base hasta incluso las sindicaciones RSS de usuarios especficos que puedan ser vistos. Puedes usar las variables %id%, %realname%, %username%, %email% y cualquier otro carcter.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Estructura de los Enlaces Permanentes para las sindicaciones RSS de autores');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Ruta para los autores');
@define('AUTHORS', 'Autores');
@define('AUTHORS_ALLOW_SELECT', 'Permitir a los visitantes mostrar mltiples autores al mismo tiempo?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Si esta opcin es activada, un checkbox estar al lado de cada autor en en la extensin lateral. Los usuarios pueden seleccionar estas casillas para ver las entradas de acuerdo a su seleccin.');
@define('AUTHOR_PLUGIN_DESC', 'Muestra una lista de autores');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Activar Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Si esta opcin es activada, la extensin utiliza las caractersticas de Smarty-Templating para producir el contenido del listado de las categoras. Si activas esto, puedes cambiar el diseo a travs del fichero "plugin_categories.tpl". Toma en cuenta que esta opcin tendr un impacto en el desempeo, si no necesitas diseos particulares, djalo deshabilitado.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Mostrar nmero de entradas por categora?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Mostrar nmero de artculos del autor?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Si esta opcin es activada, el nmero de artculos del autor se muestra al lado del nombre del autor en parntesis.');
@define('CUSTOM_ADMIN_INTERFACE', 'Interfaz de la suite de administracin personalizada');
@define('COMMENT_NOT_ADDED', 'Tu comentario no ha podido ser aadido debido a que, o bien, en esta entrada ha sido deshabilitado el envo de comentarios, ingresaste datos errneos, o tu comentario ha sido capturado por medidas anti-spam.');
@define('INSTALL_TRACKREF', 'Activar registro de "referrers"?');
@define('INSTALL_TRACKREF_DESC', 'Activando el registro de "referrers" podrs ver cuales sitios envan visitas a tus artculos. ltimamente esto esta siendo abusado frecuentemente por spammers, as que puedes deshabilitarlo si quieres.');
@define('CATEGORIES_HIDE_PARENT', 'Ocular la categora padre seleccionada?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Si restringes el listado de categoras a una categora especifica, por defecto vers la categora padre (superior) dentro del listado generado. Si deshabilitas esta opcin, el nombre de la categora padre no ser mostrado.');
@define('WARNING_NO_GROUPS_SELECTED', 'Advertencia: No haz seleccionado ningn grupo de miembros. Esto efectivamente te dejara fuera de la gerencia del grupo de usuarios, por lo tanto, tu membresa de grupo no fue cambiada.');
@define('INSTALL_RSSFETCHLIMIT', 'Entradas a mostrar en las sindicaciones');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Nmero de entradas a mostrar por cada pgina.');
@define('INSTAL_DB_UTF8', 'Activar conversin del juego de caracteres en la BD');
@define('INSTAL_DB_UTF8_DESC', 'Enva una consulta MySQL "SET NAMES" para definir el juego de caracteres requerido por la base de datos. Actvalo o desactvalo s ves caracteres extraos en tu blog.');
@define('ONTHEFLYSYNCH', 'Activar sincronizacin de medios al-vuelo');
@define('ONTHEFLYSYNCH_DESC', 'Si lo activas, Serendipity comparar la base de datos de medios con los archivos almacenados en tu servidor y sincronizar la base de datos con el contenido del directorio.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'No puedes dejar el nombre de usuario en blanco.');
@define('FURTHER_LINKS', 'Ms enlaces');
@define('FURTHER_LINKS_S9Y', 'Pgina principal de Serendipity');
@define('FURTHER_LINKS_S9Y_DOCS', 'Documentacin de Serendipity');
@define('FURTHER_LINKS_S9Y_BLOG', 'Blog oficial');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Foros');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comentario eliminado)');
@define('CURRENT_AUTHOR', 'Autor actual');
@define('WORD_NEW', 'Nuevo');
@define('SHOW_MEDIA_TOOLBAR', 'Mostrar la barra de herramientas dentro de la ventana emergente seleccin de medios?');
@define('MEDIA_KEYWORDS', 'Palabras claves de medios');
@define('MEDIA_KEYWORDS_DESC', 'Ingresa una lista palabras separadas por ";" que quisieras utilizar como palabras clave predefinidas para los elementos de medios.');
@define('MEDIA_EXIF', 'Importar informacin de imgenes EXIF/JPEG');
@define('MEDIA_EXIF_DESC', 'Si lo activas, la metadata de las imgenes EXIF/JPEG existentes ser analizada y almacenada en la base de datos para ser mostrada en la galera de medios.');
@define('MEDIA_PROP', 'Propiedades de Medios');
@define('GO_ADD_PROPERTIES', 'Ir & ingresar propiedades');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Comentario corto');
@define('MEDIA_PROPERTY_COMMENT2', 'Comentario extendido');
@define('MEDIA_PROPERTY_TITLE', 'Ttulo');
@define('MEDIA_PROP_DESC', 'Ingresa una lista de campos de propiedades separados por ";" que te gustara definir por cada archivo de medios');
@define('MEDIA_PROP_MULTIDESC', '(Puedes aadir al final de cualquier item ":MULTI" para indicar que contendr una descripcin larga en ves de slo algunos caracteres)');
@define('STYLE_OPTIONS_NONE', 'Este tema/estilo no tiene opciones especficas. Para ver como tu plantilla puede especificar opciones, lee la documentacin tcnica en www.s9y.org acerca de "Configuracin de las opciones de los estilos".');
@define('STYLE_OPTIONS', 'Opciones de Tema/estilo');
@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d extensiones.');
@define('SYNDICATION_RFC2616', 'Activar seguimiento estricto de la norma RFC2616 para sindicaciones RSS');
@define('SYNDICATION_RFC2616_DESC', 'NO forzar el seguimiento de RFC2616 significa que todos los GETs condicionales a Serendipity regresarn entradas modificadas desde la fecha de la ltima solicitud. Con esa caracterstica definida a "false", tus visitantes obtendrn todos los artculos desde su ltima solicitud, lo cual es considerado algo bueno. Sin embargo, algunos agentes como Planet tienen un comportamiento extrao, dado viola la norma RFC2616. De esta manera, si defines esta opcin como "TRUE" estars cumpliendo con la norma, pero los lectores de tus sindicaciones RSS quizs pierdan algunas entradas en sus das de ausencia. De cualquier forma, o evitas un funcionamiento adecuado de agregadores como Planet, o daas a tus lectores reales. Si ests enfrentando quejas de cualquiera de los dos, puedes cambiar esta opcin. Rerefencia: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Fecha Asociada');

/*Translate*/
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
/**/
@define('FILENAME_REASSIGNED', 'Nombre asignado automgicamente al nuevo fichero: %s');
@define('MEDIA_UPLOAD_SIZE', 'Tamao mximo de los ficheros');//'upload' removed [rlazo]
@define('MEDIA_UPLOAD_SIZE_DESC', 'Ingresa el tamao mximo en bytes de los ficheros que puedes subir al servidor. Esta opcin puede ser sobreescrita por la configuracin en el servidor en PHP.ini: upload_max_filesize, post_max_size, max_input_time, todas las anteriores tiene precedencia sobre esta opcin. Si la dejas en blanco se usarn slo los lmites definidos en el servidor.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Error: No puedes subir ficheros de ms de %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Ancho mximo de las imgenes'); //'upload' removed [rlazo]
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Ingresa la anchura mxima de las imgenes que se pueden subir al servidor en pixels.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Altura mxima de las imgenes');//'upload' removed [rlazo]
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Ingresa la altura mxima de las imgenes que se pueden subir al servidor en pixels.');
@define('MEDIA_UPLOAD_DIMERROR', 'Error: No puedes subir imgenes de ms de %s x %s pixels!');
@define('MEDIA_TARGET', 'Objetivo de este enlace');
@define('MEDIA_TARGET_JS', 'Ventana emergente (a travs de JavaScript, tamao adaptativo)');
@define('MEDIA_ENTRY', 'Entrada aislada');
@define('MEDIA_TARGET_BLANK', 'Ventana emergente (a travs de target=_blank)');
@define('MEDIA_DYN_RESIZE', 'Permitir redimensionar dinmicamente las imgenes?');
@define('MEDIA_DYN_RESIZE_DESC', 'Si lo activas, el selector de medios puede regresar imgenes en cualquier tamao solicitado a travs de una variable GET. Los resultados se colocan en la cach, de esta manera puedes crear una base de ficheros muy grande si es que haces un uso intensivo de esta caracterstica.');
@define('MEDIA_DIRECTORY_MOVED', 'El directorio y los ficheros fueron exitosamente movidos a %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'El directorio y los ficheros no pudieron ser movidos a %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'En bases de datos distintas a MySQL, iterar sobre cada artculo para reemplazar el URL del directorio antiguo con la nueva direccin no es posible. Necesitars que arreglar tus entradas de manera manual. Tambin puedes regresar tu directorio a su ubicacin original si hacer todo aquello te resulta muy incmodo.');
/*translate*/
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Activa');
@define('PLUGIN_INACTIVE', 'Inactiva');
@define('PREFERENCE_USE_JS', 'Activar el uso avanzado de JS?');
@define('PREFERENCE_USE_JS_DESC', 'Si lo activas, las secciones de JavaScript avanzado sern activadas para una mejor usabilidad, como la extensin de configuracin donde puedes utilizar el mtodo de arrastrar y soltar para reordenar las extensiones.');
@define('PREFERENCE_USE_JS_WARNING', '(Esta pgina hace uso de JavaScripting avanzado. Si ests teniendo problemas de funcionalidad, por favor desactiva el uso de JS avanzado en tus preferencias personales o desactiva el soporte para JavaScript de tu navegador)');
/*rlazo [20060722] spell checked*/

@define('INSTALL_PERMALINK_COMMENTSPATH', 'Ruta a los comentarios');
@define('PERM_SET_CHILD', 'Define los mismos permisos en todos los directorios hijos');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Extensiones prohibidas');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Eventos prohibidos');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Activar la extesin ACL para grupos de usuarios?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Si la opcin "Extensin ACL para grupos de usuarios" es activada en la configuracin, puedes especificar que grupos de usuarios son capaces de ejecutar ciertas extensiones/eventos.');
@define('DELETE_SELECTED_ENTRIES', 'Eliminar las entradas seleccionadas');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Slo mostrar aquellos autores con al menos X artculos');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Descargar archivos adjuntos y pginas estticas como entradas normales del blog?');
@define('USERCONF_CREATE', 'Deshabilitar usuario / prohibir actividad?');
@define('USERCONF_CREATE_DESC', 'Si activas esta opcin el usuario ya no podr crear o editar entradas en el blog. Cuando l vuelva a ingresar al sistema no podr hacer nada ms que desconectarse y ver su configuracin personal.');
@define('CATEGORY_HIDE_SUB', 'Ocultar las entradas realizadas en sub-categoras?');
@define('CATEGORY_HIDE_SUB_DESC', 'Por defecto, cuando se navega una categora tambin se muestran las entradas hechas en cualquiera de sus sub-categoras. Si activas esta opcin, se mostrn unicamente aquellas entradas que pertenezcan a la categora seleccionada.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
